==> org.apache.sling.scripting.sightly.compiler.java-1.0.22-1.3.1-source-release.zip: org.apache.sling.scripting.sightly.compiler.java-1.0.22-1.3.1/src/test/resources/imports.html.java <==
/*******************************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 ******************************************************************************/
package org.apache.sling.scripting.sightly.compiler.java;

import java.io.PrintWriter;
import java.util.Collection;
import javax.script.Bindings;

import org.apache.sling.scripting.sightly.java.compiler.RenderUnit;
import org.apache.sling.scripting.sightly.render.RenderContext;

import org.apache.sling.scripting.sightly.Record;


public final class Test_imports extends RenderUnit {

    @Override
    protected final void render(PrintWriter out,
                                Bindings bindings,
                                Bindings arguments,
                                RenderContext renderContext) {
// Main Template Body -----------------------------------------------------------------------------

Object _global_record = null;
Object _global_js = null;
Object _global_pojo = null;
out.write("\n");
_global_record = renderContext.call("use", Record.class.getName(), obj());
_global_js = renderContext.call("use", "script.js", obj());
_global_pojo = renderContext.call("use", "Pojo", obj());
out.write("<div></div>\n");


// End Of Main Template Body ----------------------------------------------------------------------
    }



    {
//Sub-Templates Initialization --------------------------------------------------------------------



//End of Sub-Templates Initialization -------------------------------------------------------------
    }

}

==> org.apache.sling.scripting.sightly.compiler.java-1.0.26-1.4.0-source-release.zip: org.apache.sling.scripting.sightly.compiler.java-1.0.26-1.4.0/src/test/resources/imports.html.java <==
/*******************************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 ******************************************************************************/
package org.apache.sling.scripting.sightly.compiler.java;

import java.io.PrintWriter;
import java.util.Collection;
import javax.script.Bindings;

import org.apache.sling.scripting.sightly.java.compiler.RenderUnit;
import org.apache.sling.scripting.sightly.render.RenderContext;

public final class Test_imports extends RenderUnit {

    @Override
    protected final void render(PrintWriter out,
                                Bindings bindings,
                                Bindings arguments,
                                RenderContext renderContext) {
// Main Template Body -----------------------------------------------------------------------------

Object _global_record = null;
Object _global_pojoa = null;
Object _global_pojob = null;
Object _global_js = null;
Object _global_pojo = null;
out.write("\n");
_global_record = renderContext.call("use", org.apache.sling.scripting.sightly.Record.class.getName(), obj());
_global_pojoa = renderContext.call("use", org.apache.sling.scripting.sightly.compiler.java.utils.fixture.a.TestPojo.class.getName(), obj());
_global_pojob = renderContext.call("use", org.apache.sling.scripting.sightly.compiler.java.utils.fixture.b.TestPojo.class.getName(), obj());
_global_js = renderContext.call("use", "script.js", obj());
_global_pojo = renderContext.call("use", "Pojo", obj());
out.write("<div></div>\n");


// End Of Main Template Body ----------------------------------------------------------------------
    }



    {
//Sub-Templates Initialization --------------------------------------------------------------------



//End of Sub-Templates Initialization -------------------------------------------------------------
    }

}
